@@ -1,6 +1,6 @@
 #' Set estimates as columns
 #'
-#' @param result A summarised_result.
+#' @param result A `<summarised_result>`.
 #' @param pivotEstimatesBy Names from which pivot wider the estimate values. If
 #' NULL the table will not be pivotted.
 #' @param nameStyle Name style (glue package specifications) to customise names
@@ -10,7 +10,6 @@
 #' @return A tibble.
 #'
 #' @description
-#' `r lifecycle::badge("experimental")`
 #' Pivot the estimates as new columns in result table.
 #'
 #' @export
@@ -23,13 +22,9 @@ pivotEstimates <- function(result,
                            pivotEstimatesBy = "estimate_name",
                            nameStyle = NULL) {
   # initial checks
-  assertTibble(result, columns = pivotEstimatesBy)
-  assertClass(result, "summarised_result")
-  assertCharacter(pivotEstimatesBy, null = TRUE)
-  assertCharacter(nameStyle, null = TRUE)
-  if ("estimate_type" %in% pivotEstimatesBy) {
-    cli::cli_abort("estimates cannot be pivotted by `estimate_type`.")
-  }
+  pivotEstimatesBy <- validatePivotEstimatesBy(pivotEstimatesBy = pivotEstimatesBy)
+  omopgenerics::assertCharacter(nameStyle, null = TRUE, length = 1)
+  omopgenerics::assertTable(result, columns = pivotEstimatesBy)
 
   # pivot estimates
   result_out <- result
@@ -37,15 +32,22 @@ pivotEstimates <- function(result,
     if (is.null(nameStyle)) {
       nameStyle <- paste0("{", paste0(pivotEstimatesBy, collapse = "}_{"), "}")
     }
+    if(grepl("__", nameStyle)){
+      cli::cli_warn(c("!" = "Double underscores found in 'nameStyle'. Converting to a single underscore."))
+    }
     typeNameConvert <- result |>
       dplyr::distinct(dplyr::across(dplyr::all_of(c("estimate_type", pivotEstimatesBy)))) |>
-      dplyr::mutate(estimate_type = dplyr::case_when(
-        grepl("percentage|proportion", .data$estimate_type) ~ "numeric",
-        "date" == .data$estimate_type ~ "Date",
-        .default = .data$estimate_type
-      ),
-      new_name = glue::glue(nameStyle)
+      dplyr::mutate(
+        estimate_type = dplyr::case_when(
+          grepl("percentage|proportion", .data$estimate_type) ~ "numeric",
+          "date" == .data$estimate_type ~ "Date",
+          .default = .data$estimate_type
+        ),
+        new_name = glue::glue(nameStyle, .na = "") |>
+          stringr::str_replace_all("_+", "_") |> #remove multiple _
+          stringr::str_replace_all("^_|_$", "") #remove leading/trailing _
       )
+
     result_out <- result |>
       dplyr::select(-"estimate_type") |>
       tidyr::pivot_wider(
@@ -53,6 +55,7 @@ pivotEstimates <- function(result,
         values_from = "estimate_value",
         names_glue = nameStyle
       ) |>
+      dplyr::rename_with(~ stringr::str_remove_all(., "_NA|NA_")) |>
       dplyr::mutate(
         dplyr::across(dplyr::all_of(typeNameConvert$new_name),
                       ~ asEstimateType(.x, name = deparse(substitute(.)), dict = typeNameConvert)
