@@ -2,9 +2,6 @@ test_that("addSettings", {
   x <- dplyr::tibble(
     "result_id" = as.integer(c(1, 2)),
     "cdm_name" = c("cprd", "eunomia"),
-    "result_type" = "summarised_characteristics",
-    "package_name" = c("omock", "visOmopResults"),
-    "package_version" = "0.4.0",
     "group_name" = "sex",
     "group_level" = "male",
     "strata_name" = "sex",
@@ -19,7 +16,12 @@ test_that("addSettings", {
   )
   expect_no_error(res <- omopgenerics::newSummarisedResult(
     x = x,
-    settings = dplyr::tibble("result_id" = c(1, 2), "custom" = c("A", "B"))
+    settings = dplyr::tibble(
+      "result_id" = c(1, 2),
+      "result_type" = "summarised_characteristics",
+      "package_name" = c("omock", "visOmopResults"),
+      "package_version" = "0.4.0",
+      "custom" = c("A", "B"))
   ))
 
   expect_identical(
@@ -33,12 +35,23 @@ test_that("addSettings", {
   expect_identical(settings(ress), settings(res))
   expect_identical(ress, ress |> addSettings())
 
-  res1 <- res |> filterSettings(package_name == "omock")
-  expect_true(nrow(res1) == 1)
-  expect_true(res1$result_id == 1)
-
-  res2 <- res |> filterSettings(custom == "B")
-  expect_true(nrow(res2) == 1)
-  expect_true(res2$result_id == 2)
+  expect_equal(res, addSettings(res, NULL))
 
+  expect_equal(
+    addSettings(result = res, settingsColumns = "result_type") |> colnames(),
+    c('result_id', 'cdm_name', 'group_name', 'group_level', 'strata_name',
+      'strata_level', 'variable_name', 'variable_level', 'estimate_name',
+      'estimate_type', 'estimate_value', 'additional_name', 'additional_level',
+      'result_type')
+  )
 })
+
+test_that("addSettings", {
+  results <- mockSummarisedResult()
+
+  expect_warning(
+    addSettings(results, columns = "results_type"),
+    "The `columns` argument of `addSettings\\(\\)` is deprecated"
+  )
+})
+
