@@ -17,3 +17,11 @@ test_that("pivotEstimates", {
   # expected errors
   expect_error(pivotEstimates(result, pivotEstimatesBy = "estimate_type"))
 })
+
+test_that("remove if variable_name is NA", {
+  result <- mockSummarisedResult()
+  res0 <- pivotEstimates(result, pivotEstimatesBy = c("variable_name", "variable_level", "estimate_name"))
+  expect_true(all(!c("age_NA_mean", "number subjects_NA_count", "age_NA_sd") %in% colnames(res0)))
+  expect_true(all(c("age_mean", "number subjects_count", "age_sd") %in% colnames(res0)))
+
+})
